pub struct TTest { /* private fields */ }Expand description
Welch’s t-test on two streaming sample populations.
Uses Welford’s incremental algorithm for the running mean and variance, so it does not need to store individual samples.
Implementations